@@ -53,7 +53,8 @@
 //!    are presented as `i64` and `u64`.
 //!  - Behaviors that depend on the sizes of C types like `long` are hidden.
 //!  - In some places, more human-friendly and less historical-accident names
-//!    are used.
+//!    are used (and documentation aliases are used so that the original names
+//!    can still be searched for).
 //!
 //! Things they don't do include:
 //!  - Detecting whether functions are supported at runtime.
@@ -79,6 +80,7 @@
 //! [`Arg`]: https://docs.rs/rustix/latest/rustix/path/trait.Arg.html
 
 #![deny(missing_docs)]
+#![allow(stable_features)]
 #![cfg_attr(linux_raw, deny(unsafe_code))]
 #![cfg_attr(asm, feature(asm))]
 #![cfg_attr(any(rustc_attrs, not(feature = "std")), feature(rustc_attrs))]
@@ -123,6 +125,9 @@ pub(crate) mod zstr;
 #[macro_use]
 pub(crate) mod const_assert;
 
+#[cfg_attr(libc, path = "imp/libc/mod.rs")]
+#[cfg_attr(linux_raw, path = "imp/linux_raw/mod.rs")]
+#[cfg_attr(wasi, path = "imp/wasi/mod.rs")]
 mod imp;
 
 #[cfg(not(windows))]
